@@ -6,8 +6,8 @@
 
 #include "gdbdriver.h"
 #include "exprwnd.h"
-#include <ntqregexp.h>
-#include <ntqstringlist.h>
+#include <tqregexp.h>
+#include <tqstringlist.h>
 #include <tdelocale.h>			/* i18n */
 #include <ctype.h>
 #include <stdlib.h>			/* strtol, atoi */
@@ -71,7 +71,11 @@ static GdbCmdInfo cmds[] = {
     { DCtty, "tty %s\n", GdbCmdInfo::argString },
     { DCexecutable, "file \"%s\"\n", GdbCmdInfo::argString },
     { DCtargetremote, "target remote %s\n", GdbCmdInfo::argString },
-    { DCcorefile, "core-file %s\n", GdbCmdInfo::argString },
+#ifdef __FreeBSD__
+    { DCcorefile, "target FreeBSD-core %s\n", GdbCmdInfo::argString },
+#else
+    { DCcorefile, "target core %s\n", GdbCmdInfo::argString },
+#endif
     { DCattach, "attach %s\n", GdbCmdInfo::argString },
     { DCinfolinemain, "kdbg_infolinemain\n", GdbCmdInfo::argNone },
     { DCinfolocals, "kdbg__alllocals\n", GdbCmdInfo::argNone },
@@ -124,8 +128,7 @@ static GdbCmdInfo cmds[] = {
 #define MAX_FMTLEN 200
 
 GdbDriver::GdbDriver() :
-	DebuggerDriver(),
-	m_gdbMajor(4), m_gdbMinor(16)
+	DebuggerDriver()
 {
     strcpy(m_prompt, PROMPT);
     m_promptMinLen = PROMPT_LEN;
@@ -281,37 +284,6 @@ void GdbDriver::commandFinished(CmdQueueItem* cmd)
 
     switch (cmd->m_cmd) {
     case DCinitialize:
-	// get version number from preamble
-	{
-	    int len;
-	    TQRegExp GDBVersion("\\nGDB [0-9]+\\.[0-9]+");
-	    int offset = GDBVersion.match(m_output, 0, &len);
-	    if (offset >= 0) {
-		char* start = m_output + offset + 5;	// skip "\nGDB "
-		char* end;
-		m_gdbMajor = strtol(start, &end, 10);
-		m_gdbMinor = strtol(end + 1, 0, 10);	// skip "."
-		if (start == end) {
-		    // nothing was parsed
-		    m_gdbMajor = 4;
-		    m_gdbMinor = 16;
-		}
-	    } else {
-		// assume some default version (what would make sense?)
-		m_gdbMajor = 4;
-		m_gdbMinor = 16;
-	    }
-	    // use a feasible core-file command
-	    if (m_gdbMajor > 4 || (m_gdbMajor == 4 && m_gdbMinor >= 16)) {
-#ifdef __FreeBSD__
-		cmds[DCcorefile].fmt = "target FreeBSD-core %s\n";
-#else
-		cmds[DCcorefile].fmt = "target core %s\n";
-#endif
-	    } else {
-		cmds[DCcorefile].fmt = "core-file %s\n";
-	    }
-	}
 	{
 	    /*
 	     * Check for GDB 7.1 or later; the syntax for the disassemble
@@ -1076,7 +1048,8 @@ moreStrings:
 	}
     }
     // is the string continued?
-    if (*p == ',') {
+    if (*p == ',')
+    {
 	// look ahead for another quote
 	const char* q = p+1;
 	while (isspace(*q))
@@ -1086,6 +1059,17 @@ moreStrings:
 	    p = q;
 	    goto moreStrings;
 	}
+
+	// some strings can end in <incomplete sequence ...>
+	if (strncmp(q, "<incomplete sequence", 20) == 0)
+	{
+	    p = q+20;
+	    while (*p != '\0' && *p != '>')
+		p++;
+	    if (*p != '\0') {
+		p++;		/* skip the '>' */
+	    }
+	}
     }
     /* very long strings are followed by `...' */
     if (*p == '.' && p[1] == '.' && p[2] == '.') {
@@ -2438,6 +2422,15 @@ std::list<DisassembledCode> GdbDriver::parseDisassemble(const char* output)
     while (p != end)
     {
 	DisassembledCode c;
+	// skip initial space or PC pointer ("=>", since gdb 7.1)
+	while (p != end) {
+	    if (isspace(*p))
+		++p;
+	    else if (p[0] == '=' && p[1] == '>')
+		p += 2;
+	    else
+		break;
+	}
 	const char* start = p;
 	// address
 	while (p != end && !isspace(*p))
